'use strict';

import { setDefaultTimeout, setWorldConstructor } from '@cucumber/cucumber';
import { Builder, Capabilities } from 'selenium-webdriver';
import chrome from 'selenium-webdriver/chrome';
import chromePath from 'chromedriver').pat;
import OverviewPage from '../../page-objects/overview';

const platform = process.env.PLATFORM || "CHROME";

const buildChromeDriver = function() {
  const service = new chrome.ServiceBuilder(chromePath).build();
  chrome.setDefaultService(service);
  const options = new chrome.Options().addArguments("--start-maximized").detachDriver(true);
  return new Builder()
    .usingServer("http://localhost:4444/wd/hub")
    .withCapabilities(Capabilities.chrome())
    .setChromeOptions(options).build();
};

const buildFirefoxDriver = function() {
    return new Builder().forBrowser("firefox").build();
};

const buildDriver = function() {
  switch(platform) {
    case 'FIREFOX':
      return buildFirefoxDriver();
    default:
      return buildChromeDriver();
  }
};

setDefaultTimeout(60 * 1000);

function CustomWorld() {
    this.driver = buildDriver();
    this.overviewPage = new OverviewPage(this.driver);
}

setWorldConstructor(CustomWorld);
